pub struct Point3M { /* private fields */ }Expand description
A point in three-dimensional Cartesian space measured in metres.
Each coordinate is a Metres, so a Point3M cannot contain NaN or an
infinity.
Implementations
Sourceimpl Point3M
impl Point3M
Sourcepub fn new(x: Metres, y: Metres, z: Metres) -> Self
pub fn new(x: Metres, y: Metres, z: Metres) -> Self
Constructs a point from already checked coordinates.
Sourcepub fn from_metres(x: f64, y: f64, z: f64) -> Result<Self, InterferenceError>
pub fn from_metres(x: f64, y: f64, z: f64) -> Result<Self, InterferenceError>
Checks three raw coordinates and constructs a point.
Sourcepub fn coordinates_metres(self) -> [f64; 3]
pub fn coordinates_metres(self) -> [f64; 3]
Returns the Cartesian coordinates as metres.
Sourcepub fn distance_to(self, other: Self) -> f64
pub fn distance_to(self, other: Self) -> f64
Returns the Euclidean distance to another point in metres.
Extremely separated finite coordinates can have a distance beyond the
finite f64 range. Propagation entry points reject that derived value.