pub struct RequestPreflight {
pub sampling_policy: SamplingPolicy,
pub sampling_certificate: SamplingCertificate,
pub work_estimate: WorkEstimate,
}Expand description
Successful sampling and work evidence obtained before field allocation.
Fields
sampling_policy: SamplingPolicyPolicy applied to the sampling certificate.
sampling_certificate: SamplingCertificatePhysical sampling measurements and thresholds.
work_estimate: WorkEstimateChecked work and storage counts.
Implementations
Sourceimpl RequestPreflight
impl RequestPreflight
Sourcepub fn admit(
problem: &InterferenceProblem,
plane: &SamplingPlane,
sampling_policy: SamplingPolicy,
sampling_thresholds: SamplingThresholds,
work_budget: WorkBudget,
) -> Result<Self, InterferenceError>
pub fn admit( problem: &InterferenceProblem, plane: &SamplingPlane, sampling_policy: SamplingPolicy, sampling_thresholds: SamplingThresholds, work_budget: WorkBudget, ) -> Result<Self, InterferenceError>
Classifies and budgets one request without allocating field storage.