pub struct SourceSet { /* private fields */ }Expand description
A non-empty collection of emitters in canonical stable-id order.
Implementations
Sourceimpl SourceSet
impl SourceSet
Sourcepub fn new(sources: Vec<Emitter>) -> Result<Self, InterferenceError>
pub fn new(sources: Vec<Emitter>) -> Result<Self, InterferenceError>
Validates source identities and sorts the sources by their id bytes.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether the set is empty.
This is always false for a successfully constructed SourceSet.
Sourcepub fn iter(&self) -> impl ExactSizeIterator<Item = &Emitter>
pub fn iter(&self) -> impl ExactSizeIterator<Item = &Emitter>
Iterates over sources in canonical stable-id order.