pub struct WorkEstimate {
pub cells: u64,
pub emitters: u64,
pub emitter_evaluations: u64,
pub host_bytes: u64,
pub result_bytes: u64,
pub certificate_stencil_work: u64,
}Expand description
Allocation and evaluation counts known before a field solve starts.
Fields
cells: u64Number of sampling cells.
emitters: u64Number of coherent emitters.
emitter_evaluations: u64Product of cells and emitters.
host_bytes: u64Peak bytes for the reference host phasor result.
result_bytes: u64Bytes in the two f64 result components.
certificate_stencil_work: u64Work for a seven-point certificate stencil at every cell.
Implementations
Sourceimpl WorkEstimate
impl WorkEstimate
Sourcepub fn new(cells: u64, emitters: u64) -> Result<Self, InterferenceError>
pub fn new(cells: u64, emitters: u64) -> Result<Self, InterferenceError>
Computes every work dimension with checked integer arithmetic.
This function allocates nothing and is also useful for testing or
admitting decoded counts before a SamplingPlane is constructed.
Sourcepub fn for_request(
problem: &InterferenceProblem,
plane: &SamplingPlane,
) -> Result<Self, InterferenceError>
pub fn for_request( problem: &InterferenceProblem, plane: &SamplingPlane, ) -> Result<Self, InterferenceError>
Computes a request estimate from checked domain records.