pub struct SamplingThresholds {
pub resolved_min_samples_per_wavelength: f64,
pub marginal_min_samples_per_wavelength: f64,
pub resolved_max_envelope_fraction_per_cell: f64,
pub marginal_max_envelope_fraction_per_cell: f64,
}Expand description
Explicit thresholds used to classify a SamplingCertificate.
The default resolved carrier requirement is eight samples per wavelength,
which gives four samples across the worst-case half-wavelength power
fringe. Four carrier samples (two per power fringe) is the marginal Nyquist
floor. Point-source 1/r envelope change defaults to five percent for
resolved and ten percent for marginal.
Fields
resolved_min_samples_per_wavelength: f64Comfortable carrier samples per wavelength on both axes.
marginal_min_samples_per_wavelength: f64Marginal carrier samples per wavelength on both axes.
resolved_max_envelope_fraction_per_cell: f64Comfortable maximum fractional 1/r change across a cell.
marginal_max_envelope_fraction_per_cell: f64Marginal maximum fractional 1/r change across a cell.
Implementations
Sourceimpl SamplingThresholds
impl SamplingThresholds
Sourcepub fn new(
resolved_min_samples_per_wavelength: f64,
marginal_min_samples_per_wavelength: f64,
resolved_max_envelope_fraction_per_cell: f64,
marginal_max_envelope_fraction_per_cell: f64,
) -> Result<Self, InterferenceError>
pub fn new( resolved_min_samples_per_wavelength: f64, marginal_min_samples_per_wavelength: f64, resolved_max_envelope_fraction_per_cell: f64, marginal_max_envelope_fraction_per_cell: f64, ) -> Result<Self, InterferenceError>
Validates explicit resolved and marginal classification thresholds.
Sourcepub fn validate(self) -> Result<Self, InterferenceError>
pub fn validate(self) -> Result<Self, InterferenceError>
Revalidates a threshold record, including one built with field syntax.